Class: OpenProject::PluginGenerator

Inherits:
Rails::Generators::Base
  • Object
show all
Defined in:
lib/generators/open_project/plugin/plugin_generator.rb

Overview

– copyright OpenProject is a project management system.

Copyright © 2012-2013 the OpenProject Team

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.

See doc/COPYRIGHT.md for more details. ++

Instance Method Summary collapse

Instance Method Details

#full_nameObject



24
25
26
27
28
# File 'lib/generators/open_project/plugin/plugin_generator.rb', line 24

def full_name
  @full_name ||= begin
    "openproject-#{plugin_name}"
  end
end

#generate_pluginObject

every public method is run when the generator is invoked



19
20
21
22
# File 'lib/generators/open_project/plugin/plugin_generator.rb', line 19

def generate_plugin
  plugin_dir
  lib_dir
end